==> oe_python_template_example-0.0.7.tar.gz: oe_python_template_example-0.0.7/CHANGELOG.md <==
[🧠 OE Python Template Example](https://oe-python-template-example.readthedocs.io/en/latest/)

## [0.0.7](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.0.4..0.0.7) - 2025-03-08

### ⚙️ Miscellaneous Tasks

- *(template)* Bump - ([355683b](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/355683b69c3ef67461b9d7a562c71fcd5e048ad9))


## [0.0.4](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.0.3..v0.0.4) - 2025-03-02

### 📚 Documentation

- Update - ([45fbb4d](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/45fbb4d287dc8575bbe5895f14f52186a42e8c56))


## [0.0.3](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.0.2..v0.0.3) - 2025-03-02

### ⚙️ Miscellaneous Tasks

- Docker.io username - ([afc5d08](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/afc5d08c6ccc5f6c6c3824600c4e0fdef1690154))
- Copier from repo - ([fa01793](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/fa017930245289f795bbfe9a3204f75103fd19bc))


## [0.0.2] - 2025-03-02

### ⛰️  Features

- Initial commit - ([7986b87](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/7986b87fef683b0274acc87c6a11404f13de874e))

### ⚙️ Miscellaneous Tasks

- Bump - ([21554f6](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/21554f61f5cee12c9595b71381888bfa281c8005))

## New Contributors ❤️

* @helmut-hoffer-von-ankershoffen made their first contribution

==> oe_python_template_example-0.1.4.tar.gz: oe_python_template_example-0.1.4/CHANGELOG.md <==
[🧠 OE Python Template Example](https://oe-python-template-example.readthedocs.io/en/latest/)

## [0.0.7](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.0.4..v0.0.7) - 2025-03-08

### ⚙️ Miscellaneous Tasks

- *(template)* Bump - ([355683b](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/355683b69c3ef67461b9d7a562c71fcd5e048ad9))


## [0.0.4](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.0.3..v0.0.4) - 2025-03-02

### 📚 Documentation

- Update - ([45fbb4d](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/45fbb4d287dc8575bbe5895f14f52186a42e8c56))


## [0.0.3](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/compare/v0.0.2..v0.0.3) - 2025-03-02

### ⚙️ Miscellaneous Tasks

- Docker.io username - ([afc5d08](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/afc5d08c6ccc5f6c6c3824600c4e0fdef1690154))
- Copier from repo - ([fa01793](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/fa017930245289f795bbfe9a3204f75103fd19bc))


## [0.0.2] - 2025-03-02

### ⛰️  Features

- Initial commit - ([7986b87](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/7986b87fef683b0274acc87c6a11404f13de874e))

### ⚙️ Miscellaneous Tasks

- Bump - ([21554f6](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template-example/commit/21554f61f5cee12c9595b71381888bfa281c8005))

## New Contributors ❤️

* @helmut-hoffer-von-ankershoffen made their first contribution
